pub struct BuiltinDeserializationError {
pub rust_name: &'static str,
pub kind: BuiltinDeserializationErrorKind,
}Expand description
Failed to deserialize a row from the DB response, represented by one of the types built into the driver.
Fields
rust_name: &'static strName of the Rust type used to represent the row.
kind: BuiltinDeserializationErrorKindDetailed information about the failure.